# -*-makefile-*-
#
# Copyright (C) 2007 by Juergen Beisert
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_GEODE_X11_DRIVER) += geode-x11-driver

#
# Paths and names
#
GEODE_X11_DRIVER_VERSION	:= 1.1.0
GEODE_X11_DRIVER		:= xf86-video-geode_gx1
GEODE_X11_DRIVER_URL		:= file://${PTXDIST_WORKSPACE}/local_src/xf86-video-geode_gx1
GEODE_X11_DRIVER_SOURCE		:= $(SRCDIR)/$(GEODE_X11_DRIVER)
GEODE_X11_DRIVER_DIR		:= $(BUILDDIR)/$(GEODE_X11_DRIVER)

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

geode-x11-driver_get: $(STATEDIR)/geode-x11-driver.get

$(STATEDIR)/geode-x11-driver.get: $(geode-x11-driver_get_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

$(GEODE_X11_DRIVER_SOURCE):
	@$(call targetinfo, $@)
	@$(call get, GEODE_X11_DRIVER)

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

geode-x11-driver_extract: $(STATEDIR)/geode-x11-driver.extract

$(STATEDIR)/geode-x11-driver.extract: $(geode-x11-driver_extract_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(GEODE_X11_DRIVER_DIR))
	@$(call extract, GEODE_X11_DRIVER)
	@$(call patchin, GEODE_X11_DRIVER)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

geode-x11-driver_prepare: $(STATEDIR)/geode-x11-driver.prepare

GEODE_X11_DRIVER_PATH	:= PATH=$(CROSS_PATH)
GEODE_X11_DRIVER_ENV 	:= $(CROSS_ENV)

#
# autoconf
#
GEODE_X11_DRIVER_AUTOCONF := $(CROSS_AUTOCONF_USR) \
	--disable-dependency-tracking \
	--localstatedir=/var \
	--disable-builddocs \
	--disable-static \
	--enable-shared

$(STATEDIR)/geode-x11-driver.prepare: $(geode-x11-driver_prepare_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(GEODE_X11_DRIVER_DIR)/config.cache)
	@cd $(GEODE_X11_DRIVER_DIR) && \
		$(GEODE_X11_DRIVER_PATH) $(GEODE_X11_DRIVER_ENV) \
		./configure $(GEODE_X11_DRIVER_AUTOCONF)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Compile
# As we need some support (and symbols) from the frambuffer driver, we must it
# do here. Only this stage ensures the Linux kernel is already extracted
# ----------------------------------------------------------------------------

geode-x11-driver_compile: $(STATEDIR)/geode-x11-driver.compile

$(STATEDIR)/geode-x11-driver.compile: $(geode-x11-driver_compile_deps_default)
	@$(call targetinfo, $@)
	@cp $(KERNEL_DIR)/drivers/video/geode_gx1/geode_gx1_fb.h $(SYSROOT)/usr/include/geode_gx1_fb.h
	@cd $(GEODE_X11_DRIVER_DIR) && $(GEODE_X11_DRIVER_PATH) $(MAKE) $(PARALLELMFLAGS)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

geode-x11-driver_install: $(STATEDIR)/geode-x11-driver.install

$(STATEDIR)/geode-x11-driver.install: $(geode-x11-driver_install_deps_default)
	@$(call targetinfo, $@)
	@$(call install, GEODE_X11_DRIVER)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

geode-x11-driver_targetinstall: $(STATEDIR)/geode-x11-driver.targetinstall

$(STATEDIR)/geode-x11-driver.targetinstall: $(geode-x11-driver_targetinstall_deps_default)
	@$(call targetinfo, $@)

	@$(call install_init, geode-x11-driver)
	@$(call install_fixup, geode-x11-driver,PACKAGE,geode-x11-driver)
	@$(call install_fixup, geode-x11-driver,PRIORITY,optional)
	@$(call install_fixup, geode-x11-driver,VERSION,$(GEODE_X11_DRIVER_VERSION))
	@$(call install_fixup, geode-x11-driver,SECTION,base)
	@$(call install_fixup, geode-x11-driver,AUTHOR,"Juergen Beisert <jbeisert\@netscape.net>")
	@$(call install_fixup, geode-x11-driver,DEPENDS,)
	@$(call install_fixup, geode-x11-driver,DESCRIPTION,missing)

	@$(call install_copy, geode-x11-driver, 0, 0, 0755, \
		$(GEODE_X11_DRIVER_DIR)/src/.libs/geodegx1_drv.so, \
		/usr/lib/xorg/modules/geodegx1_drv.so,y)

	@$(call install_finish, geode-x11-driver)

	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

geode-x11-driver_clean:
	@cd $(GEODE_X11_DRIVER_DIR) && $(GEODE_X11_DRIVER_PATH) $(MAKE) clean
	@rm -rf $(STATEDIR)/geode-x11-driver.*
	@rm -rf $(IMAGEDIR)/geode-x11-driver_*
	@rm -rf $(GEODE_X11_DRIVER_DIR)

# vim: syntax=make
