# -*-makefile-*-
# $Id: template 6655 2007-01-02 12:55:21Z rsc $
#
# Copyright (C) 2007 by Juergen Beisert
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_ESOUND) += esound

#
# Paths and names
#
ESOUND_VERSION	:= 0.2.37
ESOUND		:= esound-$(ESOUND_VERSION)
ESOUND_SUFFIX	:= tar.bz2
ESOUND_URL	:= ftp://gnome/bla/$(ESOUND).$(ESOUND_SUFFIX)
ESOUND_SOURCE	:= $(SRCDIR)/$(ESOUND).$(ESOUND_SUFFIX)
ESOUND_DIR	:= $(BUILDDIR)/$(ESOUND)

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

esound_get: $(STATEDIR)/esound.get

$(STATEDIR)/esound.get: $(esound_get_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

$(ESOUND_SOURCE):
	@$(call targetinfo, $@)
	@$(call get, ESOUND)

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

esound_extract: $(STATEDIR)/esound.extract

$(STATEDIR)/esound.extract: $(esound_extract_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(ESOUND_DIR))
	@$(call extract, ESOUND)
	@$(call patchin, ESOUND)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

esound_prepare: $(STATEDIR)/esound.prepare

ESOUND_PATH	:= PATH=$(CROSS_PATH)
ESOUND_ENV 	:= $(CROSS_ENV)

#
# autoconf
#
ESOUND_AUTOCONF := $(CROSS_AUTOCONF_USR) \
	--disable-dependency-tracking \
	--enable-ipv6=no \
	--enable-debugging=no \
	--enable-local-sound=yes \
	--with-libwrap=no \
	--enable-oss=no \
	--enable-arts=no \
	--disable-artstest \
	--enable-alsa=yes

$(STATEDIR)/esound.prepare: $(esound_prepare_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(ESOUND_DIR)/config.cache)
	cd $(ESOUND_DIR) && \
		$(ESOUND_PATH) $(ESOUND_ENV) \
		./configure $(ESOUND_AUTOCONF)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

esound_compile: $(STATEDIR)/esound.compile

$(STATEDIR)/esound.compile: $(esound_compile_deps_default)
	@$(call targetinfo, $@)
	cd $(ESOUND_DIR) && $(ESOUND_PATH) $(MAKE) $(PARALLELMFLAGS)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

esound_install: $(STATEDIR)/esound.install

$(STATEDIR)/esound.install: $(esound_install_deps_default)
	@$(call targetinfo, $@)
	@$(call install, ESOUND)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

esound_targetinstall: $(STATEDIR)/esound.targetinstall

$(STATEDIR)/esound.targetinstall: $(esound_targetinstall_deps_default)
	@$(call targetinfo, $@)

	@$(call install_init, esound)
	@$(call install_fixup, esound,PACKAGE,esound)
	@$(call install_fixup, esound,PRIORITY,optional)
	@$(call install_fixup, esound,VERSION,$(ESOUND_VERSION))
	@$(call install_fixup, esound,SECTION,base)
	@$(call install_fixup, esound,AUTHOR,"Robert Schwebel <r.schwebel\@pengutronix.de>")
	@$(call install_fixup, esound,DEPENDS,)
	@$(call install_fixup, esound,DESCRIPTION,missing)

# The applications
	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/esd, \
		/usr/bin/esd,y)
	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/esdrec, \
		/usr/bin/esdrec,y)
	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/esdcat, \
		/usr/bin/esdcat,y)
	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/esdctl, \
		/usr/bin/esdctl,y)
	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/esdsample, \
		/usr/bin/esdsample,y)
	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/esdfilt, \
		/usr/bin/esdfilt,y)
	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/esdloop, \
		/usr/bin/esdloop,y)
	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/esdmon, \
		/usr/bin/esdmon,y)
	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/esdplay, \
		/usr/bin/esdplay,y)
# The required libs
	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/libesd.so.0.2.37, \
		/usr/lib/libesd.so.0.2.37,y)
#	@$(call install_link, esound, libesd.so.0.2.37, \
#		/usr/lib/libesd.so)
	@$(call install_link, esound, libesd.so.0.2.37, \
		/usr/lib/libesd.so.0)
# Who needs the dsp library?
#	@$(call install_copy, esound, 0, 0, 0755, $(ESOUND_DIR)/.libs/libesddsp.so.0.2.37, \
#		/usr/lib/libesddsp.so.0.2.37,y)

ifdef PTXCONF_ROOTFS_ETC_INITD_ESOUND_DEFAULT
# install generic one
	@$(call install_copy, esound, 0, 0, 0755, \
		$(PTXDIST_TOPDIR)/generic/etc/init.d/esound, \
		/etc/init.d/esound, n)
endif

ifdef PTXCONF_ROOTFS_ETC_INITD_ESOUND_USER
# install users one
	@$(call install_copy, esound, 0, 0, 0755, \
		${PTXDIST_WORKSPACE}/projectroot/etc/init.d/esound, \
		/etc/init.d/esound, n)
endif

ifneq ($(PTXCONF_ROOTFS_ETC_INITD_ESOUND_LINK),"")
	@$(call install_copy, esound, 0, 0, 0755, /etc/rc.d)
	@$(call install_link, esound, ../init.d/cvs, \
		/etc/rc.d/$(PTXCONF_ROOTFS_ETC_INITD_ESOUND_LINK))
endif

	@$(call install_finish, esound)

	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

esound_clean:
	rm -rf $(STATEDIR)/esound.*
	rm -rf $(IMAGEDIR)/esound_*
	rm -rf $(ESOUND_DIR)

# vim: syntax=make
